@@ -38,18 +38,14 @@ from typing import (
     Callable,
     Coroutine,
     Deque,
-    Dict,
-    List,
-    Optional,
     Sequence,
-    Tuple,
     TypeVar,
     Union,
 )
 
 from . import utils
 from .activity import BaseActivity
-from .automod import AutoModAction, AutoModRule
+from .automod import AutoModRule
 from .channel import *
 from .channel import _channel_factory
 from .emoji import Emoji
@@ -109,10 +105,10 @@ class ChunkRequest:
         self.loop: asyncio.AbstractEventLoop = loop
         self.cache: bool = cache
         self.nonce: str = os.urandom(16).hex()
-        self.buffer: List[Member] = []
-        self.waiters: List[asyncio.Future[List[Member]]] = []
+        self.buffer: list[Member] = []
+        self.waiters: list[asyncio.Future[list[Member]]] = []
 
-    def add_members(self, members: List[Member]) -> None:
+    def add_members(self, members: list[Member]) -> None:
         self.buffer.extend(members)
         if self.cache:
             guild = self.resolver(self.guild_id)
@@ -124,7 +120,7 @@ class ChunkRequest:
                 if existing is None or existing.joined_at is None:
                     guild._add_member(member)
 
-    async def wait(self) -> List[Member]:
+    async def wait(self) -> list[Member]:
         future = self.loop.create_future()
         self.waiters.append(future)
         try:
@@ -132,7 +128,7 @@ class ChunkRequest:
         finally:
             self.waiters.remove(future)
 
-    def get_future(self) -> asyncio.Future[List[Member]]:
+    def get_future(self) -> asyncio.Future[list[Member]]:
         future = self.loop.create_future()
         self.waiters.append(future)
         return future
@@ -146,7 +142,9 @@ class ChunkRequest:
 _log = logging.getLogger(__name__)
 
 
-async def logging_coroutine(coroutine: Coroutine[Any, Any, T], *, info: str) -> Optional[T]:
+async def logging_coroutine(
+    coroutine: Coroutine[Any, Any, T], *, info: str
+) -> T | None:
     try:
         await coroutine
     except Exception:
@@ -157,30 +155,32 @@ class ConnectionState:
     if TYPE_CHECKING:
         _get_websocket: Callable[..., DiscordWebSocket]
         _get_client: Callable[..., Client]
-        _parsers: Dict[str, Callable[[Dict[str, Any]], None]]
+        _parsers: dict[str, Callable[[dict[str, Any]], None]]
 
     def __init__(
         self,
         *,
         dispatch: Callable,
-        handlers: Dict[str, Callable],
-        hooks: Dict[str, Callable],
+        handlers: dict[str, Callable],
+        hooks: dict[str, Callable],
         http: HTTPClient,
         loop: asyncio.AbstractEventLoop,
         **options: Any,
     ) -> None:
         self.loop: asyncio.AbstractEventLoop = loop
         self.http: HTTPClient = http
-        self.max_messages: Optional[int] = options.get("max_messages", 1000)
+        self.max_messages: int | None = options.get("max_messages", 1000)
         if self.max_messages is not None and self.max_messages <= 0:
             self.max_messages = 1000
 
         self.dispatch: Callable = dispatch
-        self.handlers: Dict[str, Callable] = handlers
-        self.hooks: Dict[str, Callable] = hooks
-        self.shard_count: Optional[int] = None
-        self._ready_task: Optional[asyncio.Task] = None
-        self.application_id: Optional[int] = utils._get_as_snowflake(options, "application_id")
+        self.handlers: dict[str, Callable] = handlers
+        self.hooks: dict[str, Callable] = hooks
+        self.shard_count: int | None = None
+        self._ready_task: asyncio.Task | None = None
+        self.application_id: int | None = utils._get_as_snowflake(
+            options, "application_id"
+        )
         self.heartbeat_timeout: float = options.get("heartbeat_timeout", 60.0)
         self.guild_ready_timeout: float = options.get("guild_ready_timeout", 2.0)
         if self.guild_ready_timeout < 0:
@@ -188,11 +188,13 @@ class ConnectionState:
 
         allowed_mentions = options.get("allowed_mentions")
 
-        if allowed_mentions is not None and not isinstance(allowed_mentions, AllowedMentions):
+        if allowed_mentions is not None and not isinstance(
+            allowed_mentions, AllowedMentions
+        ):
             raise TypeError("allowed_mentions parameter must be AllowedMentions")
 
-        self.allowed_mentions: Optional[AllowedMentions] = allowed_mentions
-        self._chunk_requests: Dict[Union[int, str], ChunkRequest] = {}
+        self.allowed_mentions: AllowedMentions | None = allowed_mentions
+        self._chunk_requests: dict[int | str, ChunkRequest] = {}
 
         activity = options.get("activity", None)
         if activity:
@@ -211,26 +213,34 @@ class ConnectionState:
         elif not isinstance(intents, Intents):
             raise TypeError(f"intents parameter must be Intent not {type(intents)!r}")
         if not intents.guilds:
-            _log.warning("Guilds intent seems to be disabled. This may cause state related issues.")
+            _log.warning(
+                "Guilds intent seems to be disabled. This may cause state related issues."
+            )
 
-        self._chunk_guilds: bool = options.get("chunk_guilds_at_startup", intents.members)
+        self._chunk_guilds: bool = options.get(
+            "chunk_guilds_at_startup", intents.members
+        )
 
         # Ensure these two are set properly
         if not intents.members and self._chunk_guilds:
-            raise ValueError("Intents.members must be enabled to chunk guilds at startup.")
+            raise ValueError(
+                "Intents.members must be enabled to chunk guilds at startup."
+            )
 
         cache_flags = options.get("member_cache_flags", None)
         if cache_flags is None:
             cache_flags = MemberCacheFlags.from_intents(intents)
         elif not isinstance(cache_flags, MemberCacheFlags):
-            raise TypeError(f"member_cache_flags parameter must be MemberCacheFlags not {type(cache_flags)!r}")
+            raise TypeError(
+                f"member_cache_flags parameter must be MemberCacheFlags not {type(cache_flags)!r}"
+            )
 
         else:
             cache_flags._verify_intents(intents)
 
         self.member_cache_flags: MemberCacheFlags = cache_flags
-        self._activity: Optional[ActivityPayload] = activity
-        self._status: Optional[str] = status
+        self._activity: ActivityPayload | None = activity
+        self._status: str | None = status
         self._intents: Intents = intents
 
         if not intents.members or cache_flags._empty:
@@ -245,8 +255,8 @@ class ConnectionState:
         self.clear()
 
     def clear(self, *, views: bool = True) -> None:
-        self.user: Optional[ClientUser] = None
-        # originallyy, this code used WeakValueDictionary to maintain references to the
+        self.user: ClientUser | None = None
+        # Originally, this code used WeakValueDictionary to maintain references to the
         # global user mapping.
 
         # However, profiling showed that this came with two cons:
@@ -258,26 +268,26 @@ class ConnectionState:
         # references now using a regular dictionary with eviction being done
         # using __del__. Testing this for memory leaks led to no discernible leaks,
         # though more testing will have to be done.
-        self._users: Dict[int, User] = {}
-        self._emojis: Dict[int, Emoji] = {}
-        self._stickers: Dict[int, GuildSticker] = {}
-        self._guilds: Dict[int, Guild] = {}
+        self._users: dict[int, User] = {}
+        self._emojis: dict[int, Emoji] = {}
+        self._stickers: dict[int, GuildSticker] = {}
+        self._guilds: dict[int, Guild] = {}
         if views:
             self._view_store: ViewStore = ViewStore(self)
         self._modal_store: ModalStore = ModalStore(self)
-        self._voice_clients: Dict[int, VoiceProtocol] = {}
+        self._voice_clients: dict[int, VoiceProtocol] = {}
 
         # LRU of max size 128
         self._private_channels: OrderedDict[int, PrivateChannel] = OrderedDict()
         # extra dict to look up private channels by user id
-        self._private_channels_by_user: Dict[int, DMChannel] = {}
+        self._private_channels_by_user: dict[int, DMChannel] = {}
         if self.max_messages is not None:
-            self._messages: Optional[Deque[Message]] = deque(maxlen=self.max_messages)
+            self._messages: Deque[Message] | None = deque(maxlen=self.max_messages)
         else:
-            self._messages: Optional[Deque[Message]] = None
+            self._messages: Deque[Message] | None = None
 
     def process_chunk_requests(
-        self, guild_id: int, nonce: Optional[str], members: List[Member], complete: bool
+        self, guild_id: int, nonce: str | None, members: list[Member], complete: bool
     ) -> None:
         removed = []
         for key, request in self._chunk_requests.items():
@@ -307,7 +317,7 @@ class ConnectionState:
             await coro(*args, **kwargs)
 
     @property
-    def self_id(self) -> Optional[int]:
+    def self_id(self) -> int | None:
         u = self.user
         return u.id if u else None
 
@@ -318,10 +328,10 @@ class ConnectionState:
         return ret
 
     @property
-    def voice_clients(self) -> List[VoiceProtocol]:
+    def voice_clients(self) -> list[VoiceProtocol]:
         return list(self._voice_clients.values())
 
-    def _get_voice_client(self, guild_id: Optional[int]) -> Optional[VoiceProtocol]:
+    def _get_voice_client(self, guild_id: int | None) -> VoiceProtocol | None:
         # the keys of self._voice_clients are ints
         return self._voice_clients.get(guild_id)  # type: ignore
 
@@ -355,7 +365,7 @@ class ConnectionState:
     def deref_user_no_intents(self, user_id: int) -> None:
         return
 
-    def get_user(self, id: Optional[int]) -> Optional[User]:
+    def get_user(self, id: int | None) -> User | None:
         # the keys of self._users are ints
         return self._users.get(id)  # type: ignore
 
@@ -370,13 +380,13 @@ class ConnectionState:
         self._stickers[sticker_id] = sticker = GuildSticker(state=self, data=data)
         return sticker
 
-    def store_view(self, view: View, message_id: Optional[int] = None) -> None:
+    def store_view(self, view: View, message_id: int | None = None) -> None:
         self._view_store.add_view(view, message_id)
 
     def store_modal(self, modal: Modal, message_id: int) -> None:
         self._modal_store.add_modal(modal, message_id)
 
-    def prevent_view_updates_for(self, message_id: int) -> Optional[View]:
+    def prevent_view_updates_for(self, message_id: int) -> View | None:
         return self._view_store.remove_message_tracking(message_id)
 
     @property
@@ -384,10 +394,10 @@ class ConnectionState:
         return self._view_store.persistent_views
 
     @property
-    def guilds(self) -> List[Guild]:
+    def guilds(self) -> list[Guild]:
         return list(self._guilds.values())
 
-    def _get_guild(self, guild_id: Optional[int]) -> Optional[Guild]:
+    def _get_guild(self, guild_id: int | None) -> Guild | None:
         # the keys of self._guilds are ints
         return self._guilds.get(guild_id)  # type: ignore
 
@@ -406,26 +416,26 @@ class ConnectionState:
         del guild
 
     @property
-    def emojis(self) -> List[Emoji]:
+    def emojis(self) -> list[Emoji]:
         return list(self._emojis.values())
 
     @property
-    def stickers(self) -> List[GuildSticker]:
+    def stickers(self) -> list[GuildSticker]:
         return list(self._stickers.values())
 
-    def get_emoji(self, emoji_id: Optional[int]) -> Optional[Emoji]:
+    def get_emoji(self, emoji_id: int | None) -> Emoji | None:
         # the keys of self._emojis are ints
         return self._emojis.get(emoji_id)  # type: ignore
 
-    def get_sticker(self, sticker_id: Optional[int]) -> Optional[GuildSticker]:
+    def get_sticker(self, sticker_id: int | None) -> GuildSticker | None:
         # the keys of self._stickers are ints
         return self._stickers.get(sticker_id)  # type: ignore
 
     @property
-    def private_channels(self) -> List[PrivateChannel]:
+    def private_channels(self) -> list[PrivateChannel]:
         return list(self._private_channels.values())
 
-    def _get_private_channel(self, channel_id: Optional[int]) -> Optional[PrivateChannel]:
+    def _get_private_channel(self, channel_id: int | None) -> PrivateChannel | None:
         try:
             # the keys of self._private_channels are ints
             value = self._private_channels[channel_id]  # type: ignore
@@ -435,7 +445,7 @@ class ConnectionState:
             self._private_channels.move_to_end(channel_id)  # type: ignore
             return value
 
-    def _get_private_channel_by_user(self, user_id: Optional[int]) -> Optional[DMChannel]:
+    def _get_private_channel_by_user(self, user_id: int | None) -> DMChannel | None:
         # the keys of self._private_channels are ints
         return self._private_channels_by_user.get(user_id)  # type: ignore
 
@@ -464,8 +474,12 @@ class ConnectionState:
             if recipient is not None:
                 self._private_channels_by_user.pop(recipient.id, None)
 
-    def _get_message(self, msg_id: Optional[int]) -> Optional[Message]:
-        return utils.find(lambda m: m.id == msg_id, reversed(self._messages)) if self._messages else None
+    def _get_message(self, msg_id: int | None) -> Message | None:
+        return (
+            utils.find(lambda m: m.id == msg_id, reversed(self._messages))
+            if self._messages
+            else None
+        )
 
     def _add_guild_from_data(self, data: GuildPayload) -> Guild:
         guild = Guild(data=data, state=self)
@@ -473,13 +487,19 @@ class ConnectionState:
         return guild
 
     def _guild_needs_chunking(self, guild: Guild) -> bool:
-        # If presences are enabled then we get back the old guild.large behavior
-        return self._chunk_guilds and not guild.chunked and not (self._intents.presences and not guild.large)
+        # If presences are enabled then we get back the old guild.large behaviour
+        return (
+            self._chunk_guilds
+            and not guild.chunked
+            and not (self._intents.presences and not guild.large)
+        )
 
-    def _get_guild_channel(self, data: MessagePayload) -> Tuple[Union[Channel, Thread], Optional[Guild]]:
+    def _get_guild_channel(
+        self, data: MessagePayload, guild_id: int | None = None
+    ) -> tuple[Channel | Thread, Guild | None]:
         channel_id = int(data["channel_id"])
         try:
-            guild = self._get_guild(int(data["guild_id"]))
+            guild = self._get_guild(int(guild_id or data["guild_id"]))
         except KeyError:
             channel = DMChannel._from_message(self, channel_id)
             guild = None
@@ -495,17 +515,19 @@ class ConnectionState:
         limit: int = 0,
         presences: bool = False,
         *,
-        nonce: Optional[str] = None,
+        nonce: str | None = None,
     ) -> None:
         ws = self._get_websocket(guild_id)  # This is ignored upstream
-        await ws.request_chunks(guild_id, query=query, limit=limit, presences=presences, nonce=nonce)
+        await ws.request_chunks(
+            guild_id, query=query, limit=limit, presences=presences, nonce=nonce
+        )
 
     async def query_members(
         self,
         guild: Guild,
         query: str,
         limit: int,
-        user_ids: List[int],
+        user_ids: list[int],
         cache: bool,
         presences: bool,
     ):
@@ -544,7 +566,9 @@ class ConnectionState:
                 # this snippet of code is basically waiting N seconds
                 # until the last GUILD_CREATE was sent
                 try:
-                    guild = await asyncio.wait_for(self._ready_state.get(), timeout=self.guild_ready_timeout)
+                    guild = await asyncio.wait_for(
+                        self._ready_state.get(), timeout=self.guild_ready_timeout
+                    )
                 except asyncio.TimeoutError:
                     break
                 else:
@@ -617,20 +641,20 @@ class ConnectionState:
     def parse_application_command_permissions_update(self, data) -> None:
         # unsure what the implementation would be like
         pass
-    
+
     def parse_auto_moderation_rule_create(self, data) -> None:
         rule = AutoModRule(state=self, data=data)
         self.dispatch("auto_moderation_rule_create", rule)
-    
+
     def parse_auto_moderation_rule_update(self, data) -> None:
         # somehow get a 'before' object?
         rule = AutoModRule(state=self, data=data)
         self.dispatch("auto_moderation_rule_update", rule)
-    
+
     def parse_auto_moderation_rule_delete(self, data) -> None:
         rule = AutoModRule(state=self, data=data)
         self.dispatch("auto_moderation_rule_delete", rule)
-    
+
     def parse_auto_moderation_action_execution(self, data) -> None:
         event = AutoModActionExecutionEvent(self, data)
         self.dispatch("auto_moderation_action_execution", event)
@@ -658,7 +682,9 @@ class ConnectionState:
     def parse_message_delete_bulk(self, data) -> None:
         raw = RawBulkMessageDeleteEvent(data)
         if self._messages:
-            found_messages = [message for message in self._messages if message.id in raw.message_ids]
+            found_messages = [
+                message for message in self._messages if message.id in raw.message_ids
+            ]
         else:
             found_messages = []
         raw.cached_messages = found_messages
@@ -690,7 +716,9 @@ class ConnectionState:
     def parse_message_reaction_add(self, data) -> None:
         emoji = data["emoji"]
         emoji_id = utils._get_as_snowflake(emoji, "id")
-        emoji = PartialEmoji.with_state(self, id=emoji_id, animated=emoji.get("animated", False), name=emoji["name"])
+        emoji = PartialEmoji.with_state(
+            self, id=emoji_id, animated=emoji.get("animated", False), name=emoji["name"]
+        )
         raw = RawReactionActionEvent(data, emoji, "REACTION_ADD")
 
         member_data = data.get("member")
@@ -771,7 +799,9 @@ class ConnectionState:
                 interaction.user.id,
                 interaction.data["custom_id"],
             )
-            asyncio.create_task(self._modal_store.dispatch(user_id, custom_id, interaction))
+            asyncio.create_task(
+                self._modal_store.dispatch(user_id, custom_id, interaction)
+            )
 
         self.dispatch("interaction", interaction)
 
@@ -898,7 +928,11 @@ class ConnectionState:
             )
             return
 
-        last_pin = utils.parse_time(data["last_pin_timestamp"]) if data["last_pin_timestamp"] else None
+        last_pin = (
+            utils.parse_time(data["last_pin_timestamp"])
+            if data["last_pin_timestamp"]
+            else None
+        )
 
         if guild is None:
             self.dispatch("private_channel_pins_update", channel, last_pin)
@@ -907,7 +941,7 @@ class ConnectionState:
 
     def parse_thread_create(self, data) -> None:
         guild_id = int(data["guild_id"])
-        guild: Optional[Guild] = self._get_guild(guild_id)
+        guild: Guild | None = self._get_guild(guild_id)
         if guild is None:
             _log.debug(
                 "THREAD_CREATE referencing an unknown guild ID: %s. Discarding",
@@ -971,7 +1005,7 @@ class ConnectionState:
 
     def parse_thread_list_sync(self, data) -> None:
         guild_id = int(data["guild_id"])
-        guild: Optional[Guild] = self._get_guild(guild_id)
+        guild: Guild | None = self._get_guild(guild_id)
         if guild is None:
             _log.debug(
                 "THREAD_LIST_SYNC referencing an unknown guild ID: %s. Discarding",
@@ -1010,7 +1044,7 @@ class ConnectionState:
 
     def parse_thread_member_update(self, data) -> None:
         guild_id = int(data["guild_id"])
-        guild: Optional[Guild] = self._get_guild(guild_id)
+        guild: Guild | None = self._get_guild(guild_id)
         if guild is None:
             _log.debug(
                 "THREAD_MEMBER_UPDATE referencing an unknown guild ID: %s. Discarding",
@@ -1019,7 +1053,7 @@ class ConnectionState:
             return
 
         thread_id = int(data["id"])
-        thread: Optional[Thread] = guild.get_thread(thread_id)
+        thread: Thread | None = guild.get_thread(thread_id)
         if thread is None:
             _log.debug(
                 "THREAD_MEMBER_UPDATE referencing an unknown thread ID: %s. Discarding",
@@ -1032,7 +1066,7 @@ class ConnectionState:
 
     def parse_thread_members_update(self, data) -> None:
         guild_id = int(data["guild_id"])
-        guild: Optional[Guild] = self._get_guild(guild_id)
+        guild: Guild | None = self._get_guild(guild_id)
         if guild is None:
             _log.debug(
                 "THREAD_MEMBERS_UPDATE referencing an unknown guild ID: %s. Discarding",
@@ -1041,7 +1075,7 @@ class ConnectionState:
             return
 
         thread_id = int(data["id"])
-        thread: Optional[Thread] = guild.get_thread(thread_id)
+        thread: Thread | None = guild.get_thread(thread_id)
         if thread is None:
             _log.debug(
                 "THREAD_MEMBERS_UPDATE referencing an unknown thread ID: %s. Discarding",
@@ -1194,7 +1228,9 @@ class ConnectionState:
         cache = cache or self.member_cache_flags.joined
         request = self._chunk_requests.get(guild.id)
         if request is None:
-            self._chunk_requests[guild.id] = request = ChunkRequest(guild.id, self.loop, self._get_guild, cache=cache)
+            self._chunk_requests[guild.id] = request = ChunkRequest(
+                guild.id, self.loop, self._get_guild, cache=cache
+            )
             await self.chunker(guild.id, nonce=request.nonce)
 
         if wait:
@@ -1270,7 +1306,7 @@ class ConnectionState:
 
         # do a cleanup of the messages cache
         if self._messages is not None:
-            self._messages: Optional[Deque[Message]] = deque(
+            self._messages: Deque[Message] | None = deque(
                 (msg for msg in self._messages if msg.guild != guild),
                 maxlen=self.max_messages,
             )
@@ -1353,7 +1389,9 @@ class ConnectionState:
 
         # the guild won't be None here
         members = [Member(guild=guild, data=member, state=self) for member in data.get("members", [])]  # type: ignore
-        _log.debug("Processed a chunk for %s members in guild ID %s.", len(members), guild_id)
+        _log.debug(
+            "Processed a chunk for %s members in guild ID %s.", len(members), guild_id
+        )
 
         if presences:
             member_dict = {str(member.id): member for member in members}
@@ -1376,8 +1414,14 @@ class ConnectionState:
             )
             return
 
-        creator = None if not data.get("creator", None) else guild.get_member(data.get("creator_id"))
-        scheduled_event = ScheduledEvent(state=self, guild=guild, creator=creator, data=data)
+        creator = (
+            None
+            if not data.get("creator", None)
+            else guild.get_member(data.get("creator_id"))
+        )
+        scheduled_event = ScheduledEvent(
+            state=self, guild=guild, creator=creator, data=data
+        )
         guild._add_scheduled_event(scheduled_event)
         self.dispatch("scheduled_event_create", scheduled_event)
 
@@ -1390,9 +1434,15 @@ class ConnectionState:
             )
             return
 
-        creator = None if not data.get("creator", None) else guild.get_member(data.get("creator_id"))
-        scheduled_event = ScheduledEvent(state=self, guild=guild, creator=creator, data=data)
-        old_event = guild.get_scheduled_event(data["id"])
+        creator = (
+            None
+            if not data.get("creator", None)
+            else guild.get_member(data.get("creator_id"))
+        )
+        scheduled_event = ScheduledEvent(
+            state=self, guild=guild, creator=creator, data=data
+        )
+        old_event = guild.get_scheduled_event(int(data["id"]))
         guild._add_scheduled_event(scheduled_event)
         self.dispatch("scheduled_event_update", old_event, scheduled_event)
 
@@ -1405,8 +1455,14 @@ class ConnectionState:
             )
             return
 
-        creator = None if not data.get("creator", None) else guild.get_member(data.get("creator_id"))
-        scheduled_event = ScheduledEvent(state=self, guild=guild, creator=creator, data=data)
+        creator = (
+            None
+            if not data.get("creator", None)
+            else guild.get_member(data.get("creator_id"))
+        )
+        scheduled_event = ScheduledEvent(
+            state=self, guild=guild, creator=creator, data=data
+        )
         scheduled_event.status = ScheduledEventStatus.canceled
         guild._remove_scheduled_event(scheduled_event)
         self.dispatch("scheduled_event_delete", scheduled_event)
@@ -1538,7 +1594,9 @@ class ConnectionState:
             if stage_instance is not None:
                 old_stage_instance = copy.copy(stage_instance)
                 stage_instance._update(data)
-                self.dispatch("stage_instance_update", old_stage_instance, stage_instance)
+                self.dispatch(
+                    "stage_instance_update", old_stage_instance, stage_instance
+                )
             else:
                 _log.debug(
                     "STAGE_INSTANCE_UPDATE referencing unknown stage instance ID: %s. Discarding.",
@@ -1572,10 +1630,23 @@ class ConnectionState:
         # self.user is *always* cached when this is called
         self_id = self.user.id  # type: ignore
         if guild is not None:
+            if int(data["user_id"]) == self_id:
+                voice = self._get_voice_client(guild.id)
+                if voice is not None:
+                    coro = voice.on_voice_state_update(data)
+                    asyncio.create_task(
+                        logging_coroutine(
+                            coro, info="Voice Protocol voice state update handler"
+                        )
+                    )
             member, before, after = guild._update_voice_state(data, channel_id)  # type: ignore
             if member is not None:
                 if flags.voice:
-                    if channel_id is None and flags._voice_only and member.id != self_id:
+                    if (
+                        channel_id is None
+                        and flags._voice_only
+                        and member.id != self_id
+                    ):
                         # Only remove from cache if we only have the voice flag enabled
                         # Member doesn't meet the Snowflake protocol currently
                         guild._remove_member(member)  # type: ignore
@@ -1589,14 +1660,6 @@ class ConnectionState:
                     data["user_id"],
                 )
 
-            if int(data["user_id"]) == self_id:
-                voice = self._get_voice_client(guild.id)
-                if voice is not None:
-                    if guild.me.voice is None:
-                        self._remove_voice_client(guild.id)
-                    coro = voice.on_voice_state_update(data)
-                    asyncio.create_task(logging_coroutine(coro, info="Voice Protocol voice state update handler"))
-
     def parse_voice_server_update(self, data) -> None:
         try:
             key_id = int(data["guild_id"])
@@ -1606,7 +1669,11 @@ class ConnectionState:
         vc = self._get_voice_client(key_id)
         if vc is not None:
             coro = vc.on_voice_server_update(data)
-            asyncio.create_task(logging_coroutine(coro, info="Voice Protocol voice server update handler"))
+            asyncio.create_task(
+                logging_coroutine(
+                    coro, info="Voice Protocol voice server update handler"
+                )
+            )
 
     def parse_typing_start(self, data) -> None:
         raw = RawTypingEvent(data)
@@ -1629,7 +1696,9 @@ class ConnectionState:
             if user is not None:
                 self.dispatch("typing", channel, user, raw.when)
 
-    def _get_typing_user(self, channel: Optional[MessageableChannel], user_id: int) -> Optional[Union[User, Member]]:
+    def _get_typing_user(
+        self, channel: MessageableChannel | None, user_id: int
+    ) -> User | Member | None:
         if isinstance(channel, DMChannel):
             return channel.recipient or self.get_user(user_id)
 
@@ -1641,12 +1710,14 @@ class ConnectionState:
 
         return self.get_user(user_id)
 
-    def _get_reaction_user(self, channel: MessageableChannel, user_id: int) -> Optional[Union[User, Member]]:
+    def _get_reaction_user(
+        self, channel: MessageableChannel, user_id: int
+    ) -> User | Member | None:
         if isinstance(channel, TextChannel):
             return channel.guild.get_member(user_id)
         return self.get_user(user_id)
 
-    def get_reaction_emoji(self, data) -> Union[Emoji, PartialEmoji]:
+    def get_reaction_emoji(self, data) -> Emoji | PartialEmoji:
         emoji_id = utils._get_as_snowflake(data, "id")
 
         if not emoji_id:
@@ -1662,7 +1733,7 @@ class ConnectionState:
                 name=data["name"],
             )
 
-    def _upgrade_partial_emoji(self, emoji: PartialEmoji) -> Union[Emoji, PartialEmoji, str]:
+    def _upgrade_partial_emoji(self, emoji: PartialEmoji) -> Emoji | PartialEmoji | str:
         emoji_id = emoji.id
         if not emoji_id:
             return emoji.name
@@ -1671,7 +1742,7 @@ class ConnectionState:
         except KeyError:
             return emoji
 
-    def get_channel(self, id: Optional[int]) -> Optional[Union[Channel, Thread]]:
+    def get_channel(self, id: int | None) -> Channel | Thread | None:
         if id is None:
             return None
 
@@ -1696,7 +1767,7 @@ class ConnectionState:
 class AutoShardedConnectionState(ConnectionState):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
-        self.shard_ids: Union[List[int], range] = []
+        self.shard_ids: list[int] | range = []
         self.shards_launched: asyncio.Event = asyncio.Event()
 
     def _update_message_references(self) -> None:
@@ -1708,7 +1779,9 @@ class AutoShardedConnectionState(ConnectionState):
             new_guild = self._get_guild(msg.guild.id)
             if new_guild is not None and new_guild is not msg.guild:
                 channel_id = msg.channel.id
-                channel = new_guild._resolve_channel(channel_id) or Object(id=channel_id)
+                channel = new_guild._resolve_channel(channel_id) or Object(
+                    id=channel_id
+                )
                 # channel will either be a TextChannel, Thread or Object
                 msg._rebind_cached_references(new_guild, channel)  # type: ignore
 
@@ -1719,11 +1792,13 @@ class AutoShardedConnectionState(ConnectionState):
         limit: int = 0,
         presences: bool = False,
         *,
-        shard_id: Optional[int] = None,
-        nonce: Optional[str] = None,
+        shard_id: int | None = None,
+        nonce: str | None = None,
     ) -> None:
         ws = self._get_websocket(guild_id, shard_id=shard_id)
-        await ws.request_chunks(guild_id, query=query, limit=limit, presences=presences, nonce=nonce)
+        await ws.request_chunks(
+            guild_id, query=query, limit=limit, presences=presences, nonce=nonce
+        )
 
     async def _delay_ready(self) -> None:
         await self.shards_launched.wait()
@@ -1734,7 +1809,9 @@ class AutoShardedConnectionState(ConnectionState):
             # this snippet of code is basically waiting N seconds
             # until the last GUILD_CREATE was sent
             try:
-                guild = await asyncio.wait_for(self._ready_state.get(), timeout=self.guild_ready_timeout)
+                guild = await asyncio.wait_for(
+                    self._ready_state.get(), timeout=self.guild_ready_timeout
+                )
             except asyncio.TimeoutError:
                 break
             else:
@@ -1745,7 +1822,9 @@ class AutoShardedConnectionState(ConnectionState):
                     )
                     if len(current_bucket) >= max_concurrency:
                         try:
-                            await utils.sane_wait_for(current_bucket, timeout=max_concurrency * 70.0)
+                            await utils.sane_wait_for(
+                                current_bucket, timeout=max_concurrency * 70.0
+                            )
                         except asyncio.TimeoutError:
                             fmt = "Shard ID %s failed to wait for chunks from a sub-bucket with length %d"
                             _log.warning(fmt, guild.shard_id, len(current_bucket))
@@ -1789,8 +1868,6 @@ class AutoShardedConnectionState(ConnectionState):
         except AttributeError:
             pass  # already been deleted somehow
 
-        # regular users cannot shard so we won't worry about it here.
-
         # clear the current task
         self._ready_task = None
 
@@ -1813,7 +1890,9 @@ class AutoShardedConnectionState(ConnectionState):
                 pass
             else:
                 self.application_id = utils._get_as_snowflake(application, "id")
-                self.application_flags = ApplicationFlags._from_value(application["flags"])
+                self.application_flags = ApplicationFlags._from_value(
+                    application["flags"]
+                )
 
         for guild_data in data["guilds"]:
             self._add_guild_from_data(guild_data)
