@@ -327,7 +327,7 @@ class BaseMESSAGE:
 
         raise NotImplementedError
 
-@misc.doc_category("Automatic generation", path="message")
+@misc.doc_category("Auto objects", path="message")
 class AutoCHANNEL:
     """
     .. versionadded:: v2.3
@@ -426,16 +426,10 @@ class AutoCHANNEL:
         if stamp - self.last_scan > self.interval:
             self.last_scan = stamp
             guild: discord.Guild = self.parent.parent.apiobject
-            client_: discord.Client = client.get_client()
+            client_: discord.Client = self.parent.parent.parent.client
             member = guild.get_member(client_.user.id)
-
-            # Possible intents bug?
             if member is None:
                 return
-            
-            # User has not verified / has not completed rules
-            if guild.me.pending:
-                return
 
             for channel in getattr(guild, self.channel_getter):
                 if channel not in self.cache:
